@@ -28,7 +28,7 @@ from re import compile
 from types import GeneratorType
 
 # Import from itools
-from itools.datatypes import Boolean, URI, is_datatype
+from itools.datatypes import Boolean, URI
 from itools.gettext import MSG
 from itools.uri import Path, Reference
 from itools.xml import XMLError, XMLParser, find_end, stream_to_str
@@ -37,6 +37,7 @@ from itools.xml import xmlns_uri
 from itools.xml import get_attr_datatype
 from itools.html import xhtml_uri
 from itools.html import stream_to_str_as_html, stream_to_str_as_xhtml
+from itools.utils import freeze
 from schema import stl_uri
 
 
@@ -272,8 +273,8 @@ def substitute(data, stack, repeat_stack, encoding='utf-8'):
 
 
 
-def stl(document=None, namespace={}, prefix=None, events=None, mode='events',
-        skip=(DOCUMENT_TYPE,)):
+def stl(document=None, namespace=freeze({}), prefix=None, events=None,
+        mode='events', skip=(DOCUMENT_TYPE,)):
     # Input
     encoding = 'utf-8'
     if events is None:
@@ -339,7 +340,7 @@ def process_start_tag(tag_uri, tag_name, attributes, stack, repeat, encoding):
         datatype = get_attr_datatype(tag_uri, tag_name, attr_uri, attr_name,
                                      attributes)
         # Boolean attributes
-        if is_datatype(datatype, Boolean):
+        if issubclass(datatype, Boolean):
             value = substitute_boolean(value, stack, repeat, encoding)
             if value is True:
                 aux[(attr_uri, attr_name)] = attr_name
